WebSocketChannel.connect constructor
Creates a new WebSocket connection.
Connects to uri using and returns a channel that can be used to
communicate over the resulting socket.
The optional protocols parameter is the same as WebSocket.connect.
Implementation
factory WebSocketChannel.connect(Uri uri, {Iterable<String>? protocols}) =>
platform.connect(uri, protocols: protocols);